pub enum WorkflowError {
UnauthorizedSkill {
skill_id: String,
version: String,
},
UnauthorizedStep {
step_index: usize,
server: String,
tool: String,
},
StepOutOfOrder {
step_index: usize,
expected: usize,
},
BudgetExceeded {
limit_units: u64,
spent_units: u64,
currency: String,
},
BudgetCurrencyMismatch {
expected_currency: String,
actual_currency: String,
},
TimeLimitExceeded {
elapsed_secs: u64,
limit_secs: u64,
},
ExecutionLimitReached {
limit: u32,
},
InvalidState(String),
SigningFailed(String),
}Expand description
Errors from the workflow authority.
Variants
The skill grant does not authorize the requested skill.
Fields
A step is not authorized by the skill grant.
Fields
StepOutOfOrder
A step is out of order (when strict ordering is required).
BudgetExceeded
The workflow budget has been exceeded.
BudgetCurrencyMismatch
A step reported cost in a currency that does not match the declared budget.
TimeLimitExceeded
The workflow time limit has been exceeded.
ExecutionLimitReached
The maximum number of executions has been reached.
InvalidState(String)
The workflow is in an invalid state for the requested operation.
SigningFailed(String)
Receipt signing failed.